@@ -1,46 +1,68 @@
-/*
- * static char *rcsid_common_client_h =
- *   "$Id: client.h 14099 2010-11-15 07:21:33Z mwedel $";
- */
-/*
-    Crossfire client, a client program for the crossfire program.
-
-    Copyright (C) 2001,2007,2010 Mark Wedel & Crossfire Development Team
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-    The author can be reached via e-mail to crossfire-devel@real-time.com
-*/
-
 /**
  * @file client.h
  * Includes various dependencies header files needed by most everything.  It
  * also declares structures and other variables that the GUI portion needs.
  */
 
-#include <config.h>
-#include <version.h>
-#include <client-types.h>
-#include <shared/newclient.h>
-#include <item.h>
+#ifndef _CLIENT_H
+#define _CLIENT_H
 
-#ifdef HAVE_DMALLOC_H
-#  include <dmalloc.h>
+#include "config.h"
+
+// This is required for 'newclient.h' to expose client variables.
+#define CLIENT_TYPES_H
+
+#include <fcntl.h>
+#include <glib.h>
+#include <stdbool.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/time.h>
+#include <sys/types.h>
+#include <time.h>
+#include <unistd.h>
+
+#include <gio/gio.h>
+
+#ifdef WIN32
+#  include <winsock2.h>
 #endif
 
-#define MULTKEYS
+#include "item.h"
+#include "shared/newclient.h"
+#include "version.h"
+
+#ifndef SOL_TCP
+#define SOL_TCP IPPROTO_TCP
+#endif
+
+#define MAX_BUF 256
+#define BIG_BUF 1024
+
+/* used to register gui callbacks to extended texts
+ * (which are supposed to be handled more friendly than raw text)*/
+typedef void (*ExtTextManager)(int flag, int type, int subtype, char* message);
+
+typedef struct TextManager{
+    int type;
+    ExtTextManager callback;
+    struct TextManager* next;
+} TextManager;
+
+/* This is how often the client checks for X events, as well as how often
+ * it performs animations (or will).  This value can be most anything.
+ * IT is only configurable because the exact value it needs to be set to
+ * has to be figured out.  This value is in microseconds (100,000 microseconds=
+ * 0.1 seconds
+ */
+#define MAX_TIME 100000
+
+/* This is the default port to connect to the server with. */
+#define EPORT 13327
+
+/* This is the default port to connect to the server with in string form. */
+#define DEFPORT "13327"
 
 #define VERSION_CS 1023
 #define VERSION_SC 1029
@@ -74,39 +96,31 @@ extern char VERSION_INFO[256];
 /*@}*/
 
 typedef struct Animations {
-    uint16  flags;
-    uint8   num_animations;             /**< Number of animations.  Value of 2
+    guint16  flags;
+    guint8   num_animations;             /**< Number of animations.  Value of 2
                                          *   means only faces[0],[1] have
                                          *   meaningful values.
                                          */
-    uint8   speed;
-    uint8   speed_left;
-    uint8   phase;
-    uint16  *faces;
+    guint8   speed;
+    guint8   speed_left;
+    guint8   phase;
+    guint16  *faces;
 
 } Animations;
 
 extern Animations animations[MAXANIM];
 
-#define CAN_SMOOTH(__SQUARE,__LEVEL) ( (                                       \
-                                            (__SQUARE.heads[__LEVEL].face==0)  \
-                                            && (__LEVEL >0)                    \
-                                        )                                      \
-                                        || (__SQUARE.smooth[layer])            \
-                                     )
-
 /**
  * Basic support for socket communications, including the file descriptor,
  * input buffer, server, server, version, etc. ClientSocket could probably
  * hold more of the global values - it could probably hold most all
  * socket/communication related values instead of globals.
  */
-typedef struct ClientSocket {
-    int fd;
-    SockList    inbuf;
+typedef struct {
+    GSocketConnection* fd;
     int cs_version, sc_version;         /**< Server versions of these
                                          */
-    int command_sent, command_received; /**< These are used for the newer
+    guint16 command_sent, command_received; /**< These are used for the newer
                                          *   'windowing' method of commands -
                                          *   number of last command sent,
                                          *   number of received confirmation
@@ -119,14 +133,16 @@ typedef struct ClientSocket {
 
 extern ClientSocket csocket;
 
-extern char *server, *client_libdir,*image_file, *sound_server;
+extern char *sound_server;
+extern const char *cache_dir, *config_dir;
 
-typedef enum Input_State {
-    Playing, Reply_One, Reply_Many, Configure_Keys, Command_Mode,
-    Metaserver_Select
+typedef enum {
+    Playing,            //< including account login, character selection
+    Reply_One, Reply_Many, Configure_Keys, Command_Mode,
+    Metaserver_Select   //< only when metaserver window is up
 } Input_State;
 
-typedef enum rangetype {
+typedef enum {
   range_bottom = -1, range_none = 0, range_bow = 1, range_magic = 2,
   range_wand = 3, range_rod = 4, range_scroll = 5, range_horn = 6,
   range_steal = 7,
@@ -224,7 +240,7 @@ typedef enum rangetype {
 #define CFG_DM_OPENGL       2
 /*@}*/
 
-extern sint16 want_config[CONFIG_NUMS], use_config[CONFIG_NUMS];
+extern gint16 want_config[CONFIG_NUMS], use_config[CONFIG_NUMS];
 
 extern const char *const config_names[CONFIG_NUMS]; /**< See common/init.c -
                                                      *   number mapping used
@@ -232,46 +248,46 @@ extern const char *const config_names[CONFIG_NUMS]; /**< See common/init.c -
                                                      *   the values.
                                                      */
 typedef struct Stat_struct {
-    sint8 Str;                          /**< Strength */
-    sint8 Dex;                          /**< Dexterity */
-    sint8 Con;                          /**< Constitution */
-    sint8 Wis;                          /**< Wisdom */
-    sint8 Cha;                          /**< Charisma */
-    sint8 Int;                          /**< Intelligence */
-    sint8 Pow;                          /**< Power */
-    sint8 wc;                           /**< Weapon Class */
-    sint8 ac;                           /**< Armour Class */
-    sint8 level;                        /**< Experience level */
-    sint16 hp;                          /**< Hit Points */
-    sint16 maxhp;                       /**< Maximum hit points */
-    sint16 sp;                          /**< Spell points for casting spells */
-    sint16 maxsp;                       /**< Maximum spell points. */
-    sint16 grace;                       /**< Spell points for using prayers. */
-    sint16 maxgrace;                    /**< Maximum spell points. */
-    sint64 exp;                         /**< Experience.  Killers gain 1/10. */
-    sint16 food;                        /**< Quantity food in stomach.
+    gint8 Str;                          /**< Strength */
+    gint8 Dex;                          /**< Dexterity */
+    gint8 Con;                          /**< Constitution */
+    gint8 Wis;                          /**< Wisdom */
+    gint8 Cha;                          /**< Charisma */
+    gint8 Int;                          /**< Intelligence */
+    gint8 Pow;                          /**< Power */
+    gint8 wc;                           /**< Weapon Class */
+    gint8 ac;                           /**< Armour Class */
+    gint8 level;                        /**< Experience level */
+    gint16 hp;                          /**< Hit Points */
+    gint16 maxhp;                       /**< Maximum hit points */
+    gint16 sp;                          /**< Spell points for casting spells */
+    gint16 maxsp;                       /**< Maximum spell points. */
+    gint16 grace;                       /**< Spell points for using prayers. */
+    gint16 maxgrace;                    /**< Maximum spell points. */
+    gint64 exp;                         /**< Experience.  Killers gain 1/10. */
+    gint16 food;                        /**< Quantity food in stomach.
                                          *   0 = starved.
                                          */
-    sint16 dam;                         /**< How much damage this object does
+    gint16 dam;                         /**< How much damage this object does
                                          *   for each hit
                                          */
-    sint32 speed;                       /**< Speed (is displayed as a float) */
-    sint32 weapon_sp;                   /**< Weapon speed (displayed in client
+    gint32 speed;                       /**< Speed (is displayed as a float) */
+    gint32 weapon_sp;                   /**< Weapon speed (displayed in client
                                          *   as a float)
                                          */
-    uint32 attuned;                     /**< Spell paths to which the player is
+    guint32 attuned;                     /**< Spell paths to which the player is
                                          *   attuned
                                          */
-    uint32 repelled;                    /**< Spell paths to which the player is
+    guint32 repelled;                    /**< Spell paths to which the player is
                                          *   repelled
                                          */
-    uint32 denied;                      /**< Spell paths denied to the player*/
-    uint16 flags;                       /**< Contains fire on/run on flags */
-    sint16 resists[30];                 /**< Resistant values */
-    uint32 resist_change:1;             /**< Resistant value change flag */
-    sint16 skill_level[MAX_SKILL];      /**< Level of known skills */
-    sint64 skill_exp[MAX_SKILL];        /**< Experience points for skills */
-    uint32 weight_limit;                /**< Carrying weight limit */
+    guint32 denied;                      /**< Spell paths denied to the player*/
+    guint16 flags;                       /**< Contains fire on/run on flags */
+    gint16 resists[30];                 /**< Resistant values */
+    guint32 resist_change:1;             /**< Resistant value change flag */
+    gint16 skill_level[MAX_SKILL];      /**< Level of known skills */
+    gint64 skill_exp[MAX_SKILL];        /**< Experience points for skills */
+    guint32 weight_limit;                /**< Carrying weight limit */
 } Stats;
 
 typedef struct Spell_struct {
@@ -279,30 +295,30 @@ typedef struct Spell_struct {
     char name[256];                     /**< One length byte plus data       */
     char message[10000];                /**< This is huge, the packets can't
                                          *   be much bigger than this anyway */
-    uint32 tag;                         /**< Unique ID number for a spell so
+    guint32 tag;                         /**< Unique ID number for a spell so
                                          *   updspell etc can operate on it. */
-    uint16 level;                       /**< The casting level of the spell. */
-    uint16 time;                        /**< Casting time in server ticks.   */
-    uint16 sp;                          /**< Mana per cast; may be zero.     */
-    uint16 grace;                       /**< Grace per cast; may be zero.    */
-    uint16 dam;                         /**< Damage done by spell though the
+    guint16 level;                       /**< The casting level of the spell. */
+    guint16 time;                        /**< Casting time in server ticks.   */
+    guint16 sp;                          /**< Mana per cast; may be zero.     */
+    guint16 grace;                       /**< Grace per cast; may be zero.    */
+    guint16 dam;                         /**< Damage done by spell though the
                                          *   meaning is spell dependent and
                                          *   actual damage may depend on how
                                          *   the spell works.                */
-    uint8 skill_number;                 /**< The index in the skill arrays,
+    guint8 skill_number;                 /**< The index in the skill arrays,
                                          *   plus CS_STAT_SKILLINFO. 0: no
                                          *   skill used for cast.  See also:
                                          *   request_info skill_info         */
     char *skill;                        /**< Pointer to the skill name,
                                          *   derived from the skill number.  */
-    uint32 path;                        /**< The bitmask of paths this spell
+    guint32 path;                        /**< The bitmask of paths this spell
                                          *   belongs to.  See request_info
                                          *   spell_paths and stats about
                                          *   attunement, repulsion, etc.     */
-    sint32 face;                        /**< A face ID that may be used to
+    gint32 face;                        /**< A face ID that may be used to
                                          *   show a graphic representation
                                          *   of the spell.                   */
-    uint8 usage;                        /**< Spellmon 2 data.  Values are:
+    guint8 usage;                        /**< Spellmon 2 data.  Values are:
                                          *   0: No argument required.
                                          *   1: Requires other spell name.
                                          *   2: Freeform string is optional.
@@ -320,39 +336,42 @@ typedef struct Player_Struct {
     item        *below;                 /**< Items below the player
                                          *   (pl.below->inv) */
     item        *container;             /**< open container */
-    uint16      count_left;             /**< count for commands */
+    guint16      count_left;             /**< count for commands */
     Input_State input_state;            /**< What the input state is */
     char        last_command[MAX_BUF];  /**< Last command entered */
     char        input_text[MAX_BUF];    /**< keys typed (for long commands) */
     item        *ranges[range_size];    /**< Object that is used for that */
                                         /**< range type */
-    uint8       ready_spell;            /**< Index to spell that is readied */
+    guint8       ready_spell;            /**< Index to spell that is readied */
     char        spells[255][40];        /**< List of all the spells the */
                                         /**< player knows */
     Stats       stats;                  /**< Player stats */
     Spell       *spelldata;             /**< List of spells known */
     char        title[MAX_BUF];         /**< Title of character */
     char        range[MAX_BUF];         /**< Range attack chosen */
-    uint32      spells_updated;         /**< Whether or not spells updated */
-    uint32      fire_on:1;              /**< True if fire key is pressed */
-    uint32      run_on:1;               /**< True if run key is on */
-    uint32      meta_on:1;              /**< True if fire key is pressed */
-    uint32      alt_on:1;               /**< True if fire key is pressed */
-    uint32      no_echo:1;              /**< If TRUE, don't echo keystrokes */
-    uint32      count;                  /**< Repeat count on command */
-    uint16      mmapx, mmapy;           /**< size of magic map */
-    uint16      pmapx, pmapy;           /**< Where the player is on the magic
+    guint32      spells_updated;         /**< Whether or not spells updated */
+    guint32      fire_on:1;              /**< True if fire key is pressed */
+    guint32      run_on:1;               /**< True if run key is on */
+    guint32      meta_on:1;              /**< True if fire key is pressed */
+    guint32      alt_on:1;               /**< True if fire key is pressed */
+    guint32      no_echo:1;              /**< If TRUE, don't echo keystrokes */
+    guint32      count;                  /**< Repeat count on command */
+    guint16      mmapx, mmapy;           /**< size of magic map */
+    guint16      pmapx, pmapy;           /**< Where the player is on the magic
                                          *   map */
-    uint8       *magicmap;              /**< Magic map data */
-    uint8       showmagic;              /**< If 0, show the normal map,
+    guint8       *magicmap;              /**< Magic map data */
+    guint8       showmagic;              /**< If 0, show the normal map,
                                          *   otherwise show the magic map. */
-    uint16      mapxres,mapyres;        /**< Resolution to draw on the magic
+    guint16      mapxres,mapyres;        /**< Resolution to draw on the magic
                                          *   map. Only used in client-specific
                                          *   code, so it should move there. */
-#ifdef MULTKEYS
-    char    name[ 40 ];                 /**< Player's name, for player-specific
-                                         *   key files */
-#endif
+    char        *name;                  /**< Name of PC, set and freed in account.c
+                                         *   play_character() (using data returned
+                                         *   from server to AccountPlayersCmd, via
+                                         *   character_choose window,
+                                         *   OR in
+                                         *   send_create_player_to_server() when
+                                         *   new character created. */
 } Client_Player;
 
 /**
@@ -371,8 +390,8 @@ typedef struct Player_Struct {
 /*@}*/
 
 typedef struct FaceSets_struct {
-    uint8   setnum;                     /**<  */
-    uint8   fallback;                   /**<  */
+    guint8   setnum;                     /**<  */
+    guint8   fallback;                   /**<  */
     char    *prefix;                    /**<  */
     char    *fullname;                  /**<  */
     char    *size;                      /**<  */
@@ -385,18 +404,18 @@ typedef struct FaceSets_struct {
  * namespace collision.
  */
 typedef struct Face_Information_struct {
-    uint8   faceset;
+    guint8   faceset;
     char    *want_faceset;
-    sint16  num_images;
-    uint32  bmaps_checksum, old_bmaps_checksum;
+    gint16  num_images;
+    guint32  bmaps_checksum, old_bmaps_checksum;
     /**
      * Just for debugging/logging purposes.  This is cleared on each new
      * server connection.  This may not be 100% precise (as we increment
      * cache_hits when we find a suitable image to load - if the data is bad,
      * that would count as both a hit and miss.
      */
-    sint16  cache_hits, cache_misses;
-    uint8   have_faceset_info;          /**< Simple value to know if there is
+    gint16  cache_hits, cache_misses;
+    guint8   have_faceset_info;          /**< Simple value to know if there is
                                          *   data in facesets[].
                                          */
     FaceSets    facesets[MAX_FACE_SETS];
@@ -411,62 +430,14 @@ extern int last_used_skills[MAX_SKILL+1]; /**< maps position to skill id with
                                            *  trailing zero as stop mark.
                                            */
 
-typedef enum LogLevel {
-  LOG_DEBUG = 0, LOG_INFO = 1, LOG_WARNING = 2, LOG_ERROR = 3, LOG_CRITICAL = 4
+typedef enum {
+    LOG_DEBUG = 0,      ///< Useful debugging information
+    LOG_INFO = 1,       ///< Minor, non-harmful issues
+    LOG_WARNING = 2,    ///< Warning that something might not work
+    LOG_ERROR = 3,      ///< Warning that something definitely didn't work
+    LOG_CRITICAL = 4    ///< Fatal crash-worthy error
 } LogLevel;
 
-typedef struct LogEntry {
-    char* message;
-    char* origin;
-    LogLevel level;
-    struct LogEntry* next;
-} LogEntry;
-extern LogEntry* LogFirst;
-extern LogEntry* LogLast;
-extern int logcount;
-typedef void (*LogListener)(LogEntry*);
-#define MAX_LOGS 200
-#define LOG_APPEND(_Entry) if (LogLast) {\
-    LogLast->next=_Entry;\
-  } else {\
-    LogFirst=_Entry;\
-  };\
-  LogLast=_Entry;_Entry->next=NULL;\
-  if (++logcount > MAX_LOGS)\
-  {\
-      LogEntry* old = LogFirst;\
-      LogFirst = LogFirst -> next;\
-      if (old->message) free (old->message);\
-      if (old->origin) free (old->origin);\
-  }
-#define LOG_NEW_ENTRY (LogEntry*)calloc(1,sizeof(LogEntry))
-#define LOG_SETMESSAGE(_Entry,_msg) free(_Entry->message);_Entry->message=strdup(_msg)
-#define LOG_SETORIGIN(_Entry,_orig) free(_Entry->origin);_Entry->origin=strdup(_orig)
-
-typedef struct PipeLog {
-    char* name;
-    LogLevel level;
-    int log;                            /**< To log or not to log. */
-}PipeLog;
-
-#define CHILD_STDIN      1
-#define CHILD_STDOUT     2
-#define CHILD_STDERR     4
-#define CHILD_SILENTFAIL 8
-#define CHILD_TUBE       (CHILD_STDIN|CHILD_STDOUT|CHILD_STDERR)
-typedef struct ChildProcess{
-    char* name;
-    int flag;
-    int pid;
-    int tube[3];
-    PipeLog logger[3];
-    struct ChildProcess* next;
-}ChildProcess;
-
-#define CHILD_PIPEIN(__child)  (__child->tube[0])
-#define CHILD_PIPEOUT(__child) (__child->tube[1])
-#define CHILD_PIPEERR(__child) (__child->tube[2])
-
 /**
  * Translation of the STAT_RES names into printable names, in matching order.
  */
@@ -474,9 +445,7 @@ typedef struct ChildProcess{
 
 extern const char *const resists_name[NUM_RESISTS];
 extern char *meta_server;
-extern int meta_port;
-extern int metaserver_on, metaserver2_on, serverloginmethod, wantloginmethod;
-extern uint32   tick;
+extern int serverloginmethod, wantloginmethod;
 
 /**
  * Holds the names that correspond to skill and resistance numbers.
@@ -488,14 +457,14 @@ typedef struct {
 
 extern NameMapping skill_mapping[MAX_SKILL], resist_mapping[NUM_RESISTS];
 
-extern uint64   *exp_table;
-extern uint16   exp_table_max;
+extern guint64   *exp_table;
+extern guint16   exp_table_max;
 
 /**
  * Map size the client will request the map to be.  The bigger it is, more
  * memory it will use.
  */
-#define MAP_MAX_SIZE 31
+#define MAP_MAX_SIZE 25
 
 /**
  * This is the smallest the map structure used for the client can be.  It
@@ -530,8 +499,8 @@ extern uint16   exp_table_max;
  */
 typedef struct Cache_Entry {
     char    *filename;
-    uint32  checksum;
-    uint32  ispublic:1;
+    guint32  checksum;
+    guint32  ispublic:1;
     void    *image_data;
     struct Cache_Entry  *next;
 } Cache_Entry;
@@ -599,8 +568,8 @@ extern int stat_points, stat_min, stat_maximum;
  */
 struct Stat_Mapping {
     const char  *widget_suffix; /* within the glade file, suffix used on widget */
-    uint8       cs_value;       /* within the protocol, the CS_STAT value */
-    uint8       rc_offset;      /* Offset into the stat_adj array */
+    guint8       cs_value;       /* within the protocol, the CS_STAT value */
+    guint8       rc_offset;      /* Offset into the stat_adj array */
 };
 
 extern struct Stat_Mapping stat_mapping[NUM_NEW_CHAR_STATS];
@@ -626,7 +595,7 @@ typedef struct Race_Class_Info {
     char    *arch_name;     /* Name of the archetype this correponds to */
     char    *public_name;   /* Public (human readadable) name */
     char    *description;   /* Description of the race/class */
-    sint8   stat_adj[NUM_NEW_CHAR_STATS];   /* Adjustment values */
+    gint8   stat_adj[NUM_NEW_CHAR_STATS];   /* Adjustment values */
     int     num_rc_choice;                  /* Size of following array */
     struct RC_Choice    *rc_choice;         /* array of choices */
 } Race_Class_Info;
@@ -640,6 +609,7 @@ typedef struct Starting_Map_Info {
 extern Race_Class_Info *races, *classes;
 extern Starting_Map_Info *starting_map_info;
 extern int starting_map_number;
+extern int maxfd;
 
 /* End of commands.c data, start of other declarations */
 #ifndef MIN
@@ -657,30 +627,69 @@ extern int starting_map_number;
 #define INFO_RULES 3
 /*@}*/
 
-/**
- * @defgroup CONVERT_FILESPEC CONVERT_FILESPEC_TO_OS_FORMAT declarations.
- * Support for converting forward-slash delimited filespecs to WIN32 format
- * when clients are built for that platform.  Client code that uses a path
- * reference builds paths in a buffer using forward slashes.  After
- * constructing the path, CONVERT_FILESPEC_TO_OS_FORMAT() is used on the
- * buffer.  On non-WIN32 platforms, the macro does nothing and the path is
- * used as-is.  On WIN32 platforms forward slashes found in the buffer are
- * converted to backslash characters.
- */
-/*@{*/
-#ifndef WIN32
-#define CONVERT_FILESPEC_TO_OS_FORMAT(path)
-#else
-extern void replace_chars_with_string(
-   char* buffer, const uint16 buffer_size,
-       const char find, const char* replace);
-#define CONVERT_FILESPEC_TO_OS_FORMAT(path) \
-   replace_chars_with_string((path), sizeof(path), '/', "\\")
-#endif
-/*@}*/
+#define CLIENT_ERROR client_error_quark()
+
+inline GQuark client_error_quark() {
+    return g_quark_from_static_string("client-error-quark");
+}
+
+enum ClientError {
+    CLIENT_ERROR_TOOBIG
+};
 
-#ifndef CPROTO
 /* We need to declare most of the structs before we can include this */
-#include <proto.h>
-#endif
+#include "proto.h"
 
+/**
+ * Open a socket to the given hostname and store connection information.
+ *
+ * @param hostname Host name or address of the server
+ */
+extern void client_connect(const char *hostname);
+
+/**
+ * Closes the connection to the server.  It seems better to have it one place
+ * here than the same logic sprinkled about in half a dozen locations.  It is
+ * also useful in that if this logic does change, there is just one place to
+ * update it.
+ */
+extern void client_disconnect(void);
+
+/**
+ * This function negotiates the characteriistics of a connection to the
+ * server.  Negotiation consists of asking the server for commands it wants,
+ * and checking protocol version for compatibility.  Serious incompatibilities
+ * abort the connection.
+ *
+ * @param sound Non-zero to ask for sound and music commands.
+ */
+extern void client_negotiate(int sound);
+
+/**
+ * Ask the server for the given map size.
+ */
+extern void client_mapsize(int width, int height);
+
+/**
+ * Read available packets from the server and handle commands until there are
+ * no more, or if a socket error occurs.
+ */
+extern void client_run(void);
+
+/**
+ * Write the given data to the server.
+ */
+extern bool client_write(const void *buf, int len);
+
+extern bool client_is_connected(void);
+
+/**
+ * Return a source triggered when input from the server is available.
+ */
+extern GSource *client_get_source(void);
+
+extern GTimer* global_time;
+
+extern bool debug_protocol;
+
+#endif
