@@ -1,48 +1,37 @@
-const char * const rcsid_common_item_c =
-    "$Id: item.c 12356 2010-01-20 08:07:04Z mwedel $";
 /*
-    Crossfire client, a client program for the crossfire program.
-
-    Copyright (C) 2001,2010 Mark Wedel & Crossfire Development Team
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-    The author can be reached via e-mail to crossfire-devel@real-time.com
-*/
+ * Crossfire -- cooperative multi-player graphical RPG and adventure game
+ *
+ * Copyright (c) 1999-2013 Mark Wedel and the Crossfire Development Team
+ * Copyright (c) 1992 Frank Tore Johansen
+ *
+ * Crossfire is free software and comes with ABSOLUTELY NO WARRANTY. You are
+ * welcome to redistribute it under certain conditions. For details, please
+ * see COPYING and LICENSE.
+ *
+ * The authors can be reached via e-mail at <crossfire@metalforge.org>.
+ */
 
 /**
- * @file common/item.c
+ * @file
  * Provides functions that process items in various ways.
  */
 
+#include "client.h"
+
 #include <ctype.h>      /* needed for isdigit */
-#include <client.h>
-#include <item.h>
-#include <shared/newclient.h>
-#include <external.h>
-#include <script.h>
+
+#include "external.h"
+#include "item.h"
+#include "script.h"
 
 static item *free_items;        /* the list of free (unused) items */
 static item *player, *map;      /* these lists contains rest of items */
-                                /* player = pl->ob, map = pl->below */
+/* player = pl->ob, map = pl->below */
 
 #define NROF_ITEMS 50           /* how many items are reserved initially */
-                                /* for the item spool */
-
-#include <item-types.h>
+/* for the item spool */
 
+#include "item-types.h"
 
 /* This uses the item_types table above.  We try to figure out if
  * name has a match above.  Matching is done pretty loosely - however
@@ -50,7 +39,8 @@ static item *player, *map;      /* these lists contains rest of items */
  * We return the 'type' (matching array element above), 255 if no match
  * (so unknown objects put at the end)
  */
-uint8 get_type_from_name(const char *name) {
+guint8 get_type_from_name(const char *name)
+{
     int type, pos;
 
     for (type = 0; type < NUM_ITEM_TYPES; type++) {
@@ -58,7 +48,7 @@ uint8 get_type_from_name(const char *name) {
         while (item_types[type][pos] != NULL) {
             /* Only search at start of line */
             if (item_types[type][pos][0] == '^') {
-                if (!strncasecmp(name, item_types[type][pos]+1, strlen(item_types[type][pos]+1))) {
+                if (!g_ascii_strncasecmp(name, item_types[type][pos]+1, strlen(item_types[type][pos]+1))) {
                     return type;
                 }
             }
@@ -79,7 +69,8 @@ uint8 get_type_from_name(const char *name) {
 /* Does what is says - inserts newitem before the object.
  * the parameters can not be null
  */
-static void insert_item_before_item(item *newitem, item *before) {
+static void insert_item_before_item(item *newitem, item *before)
+{
     if (before->prev) {
         before->prev->next = newitem;
     } else {
@@ -97,7 +88,8 @@ static void insert_item_before_item(item *newitem, item *before) {
 }
 
 /* Item it has gotten an item type, so we need to resort its location */
-void update_item_sort(item *it) {
+void update_item_sort(item *it)
+{
     item *itmp, *last = NULL;
 
     /* If not in some environment or the map, return */
@@ -114,21 +106,27 @@ void update_item_sort(item *it) {
      * if you just equip something.
      */
     if (it->prev && it->prev->type == it->type &&
-        it->prev->locked == it->locked &&
-        !strcasecmp(it->prev->s_name, it->s_name)) {
+            it->prev->locked == it->locked &&
+            !g_ascii_strcasecmp(it->prev->s_name, it->s_name)) {
         return;
     }
 
     if (it->next && it->next->type == it->type &&
-        it->next->locked == it->locked &&
-        !strcasecmp(it->next->s_name, it->s_name)) {
+            it->next->locked == it->locked &&
+            !g_ascii_strcasecmp(it->next->s_name, it->s_name)) {
         return;
     }
 
     /* Remove this item from the list */
-    if (it->prev) it->prev->next = it->next;
-    if (it->next) it->next->prev = it->prev;
-    if (it->env->inv == it) it->env->inv = it->next;
+    if (it->prev) {
+        it->prev->next = it->next;
+    }
+    if (it->next) {
+        it->next->prev = it->prev;
+    }
+    if (it->env->inv == it) {
+        it->env->inv = it->next;
+    }
 
     for (itmp = it->env->inv; itmp != NULL; itmp = itmp->next) {
         last = itmp;
@@ -149,13 +147,19 @@ void update_item_sort(item *it) {
              */
 
             /* applied items go first */
-            if (itmp->applied) continue;
+            if (itmp->applied) {
+                continue;
+            }
             /* put locked items before others */
-            if (itmp->locked && !it->locked) continue;
+            if (itmp->locked && !it->locked) {
+                continue;
+            }
 #endif
 
             /* Now alphabetise */
-            if (strcasecmp(itmp->s_name, it->s_name) < 0) continue;
+            if (g_ascii_strcasecmp(itmp->s_name, it->s_name) < 0) {
+                continue;
+            }
 
             /* IF we got here, it means it passed all our sorting tests */
             insert_item_before_item(it, itmp);
@@ -183,8 +187,9 @@ void update_item_sort(item *it) {
  * call to get_number().
  * It is currently only used by the query_name() function.
  */
-const char *get_number(uint32 i) {
-    static const char numbers[21][20] = {
+const char *get_number(guint32 i)
+{
+    static const char *numbers[] = {
         "no", "a", "two", "three", "four",
         "five", "six", "seven", "eight", "nine",
         "ten", "eleven", "twelve", "thirteen", "fourteen",
@@ -193,11 +198,6 @@ const char *get_number(uint32 i) {
     };
     static char buf[MAX_BUF];
 
-    if (i < 0) {
-        snprintf(buf, sizeof(buf), "negative");
-        return buf;
-    }
-
     if (i <= 20) {
         return numbers[i];
     } else {
@@ -210,8 +210,9 @@ const char *get_number(uint32 i) {
  *  new_item() returns pointer to new item which
  *  is allocated and initialized correctly
  */
-static item *new_item(void) {
-    item *op = malloc(sizeof(item));
+static item *new_item(void)
+{
+    item *op = g_malloc(sizeof(item));
 
     if (!op) {
         exit(0);
@@ -226,7 +227,7 @@ static item *new_item(void) {
     op->tag = 0;
     op->face = 0;
     op->weight = 0;
-    op->magical = op->cursed = op->damned = 0;
+    op->magical = op->cursed = op->damned = op->blessed = 0;
     op->unpaid = op->locked = op->applied = 0;
     op->flagsval = 0;
     op->animation_id = 0;
@@ -242,7 +243,8 @@ static item *new_item(void) {
 /*
  *  alloc_items() returns pointer to list of allocated objects
  */
-static item *alloc_items(int nrof) {
+static item *alloc_items(int nrof)
+{
     item *op, *list;
     int i;
 
@@ -259,7 +261,8 @@ static item *alloc_items(int nrof) {
 /*
  *  free_items() frees all allocated items from list
  */
-void free_all_items(item *op) {
+void free_all_items(item *op)
+{
     item *tmp;
 
     while (op) {
@@ -275,7 +278,8 @@ void free_all_items(item *op) {
 /*
  *  Recursive function, used by locate_item()
  */
-static item *locate_item_from_item(item *op, sint32 tag) {
+static item *locate_item_from_item(item *op, gint32 tag)
+{
     item *tmp;
 
     for (; op; op = op->next) {
@@ -293,7 +297,8 @@ static item *locate_item_from_item(item *op, sint32 tag) {
  *  locate_item() returns pointer to the item which tag is given
  *  as parameter or if item is not found returns NULL
  */
-item *locate_item(sint32 tag) {
+item *locate_item(gint32 tag)
+{
     item *op;
 
     if (tag == 0) {
@@ -312,8 +317,9 @@ item *locate_item(sint32 tag) {
         return cpl.container;
     }
 
-    if (cpl.container && (op = locate_item_from_item(cpl.container->inv, tag)) != NULL)
+    if (cpl.container && (op = locate_item_from_item(cpl.container->inv, tag)) != NULL) {
         return op;
+    }
 
     return NULL;
 }
@@ -322,7 +328,8 @@ item *locate_item(sint32 tag) {
  *  remove_item() inserts op the the list of free items
  *  Note that it don't clear all fields in item
  */
-void remove_item(item *op) {
+void remove_item(item *op)
+{
     /* IF no op, or it is the player */
     if (!op || op == player || op == map) {
         return;
@@ -369,7 +376,7 @@ void remove_item(item *op) {
     op->tag = 0;
     op->face = 0;
     op->weight = 0;
-    op->magical = op->cursed = op->damned = 0;
+    op->magical = op->cursed = op->damned = op->blessed = 0;
     op->unpaid = op->locked = op->applied = 0;
     op->flagsval = 0;
     op->animation_id = 0;
@@ -383,7 +390,8 @@ void remove_item(item *op) {
 /*
  *  remove_item_inventory() recursive frees items inventory
  */
-void remove_item_inventory(item *op) {
+void remove_item_inventory(item *op)
+{
     if (!op) {
         return;
     }
@@ -399,7 +407,8 @@ void remove_item_inventory(item *op) {
 /*
  *  add_item() adds item op to end of the inventory of item env
  */
-static void add_item(item *env, item *op) {
+static void add_item(item *env, item *op)
+{
     item *tmp;
 
     for (tmp = env->inv; tmp && tmp->next; tmp = tmp->next)
@@ -423,7 +432,8 @@ static void add_item(item *env, item *op) {
  *  and sets its tag field and clears locked flag (all other fields
  *  are unitialized and may contain random values)
  */
-item *create_new_item(item *env, sint32 tag) {
+item *create_new_item(item *env, gint32 tag)
+{
     item *op;
 
     if (!free_items) {
@@ -445,7 +455,8 @@ item *create_new_item(item *env, sint32 tag) {
     return op;
 }
 
-int num_free_items(void) {
+int num_free_items(void)
+{
     item *tmp;
     int count = 0;
 
@@ -463,7 +474,8 @@ static const char *const apply_string[] = {
     "", " (readied)", " (wielded)", " (worn)", " (active)", " (applied)",
 };
 
-static void set_flag_string(item *op) {
+static void set_flag_string(item *op)
+{
     op->flags[0] = 0;
 
     if (op->locked) {
@@ -485,6 +497,9 @@ static void set_flag_string(item *op) {
     if (op->cursed) {
         strcat(op->flags, " (cursed)");
     }
+    if (op->blessed) {
+        strcat(op->flags, " (blessed)");
+    }
     if (op->magical) {
         strcat(op->flags, " (magic)");
     }
@@ -493,11 +508,13 @@ static void set_flag_string(item *op) {
     }
 }
 
-static void get_flags(item *op, uint16 flags) {
+static void get_flags(item *op, guint16 flags)
+{
     op->was_open = op->open;
     op->open     = flags&F_OPEN    ? 1 : 0;
     op->damned   = flags&F_DAMNED  ? 1 : 0;
     op->cursed   = flags&F_CURSED  ? 1 : 0;
+    op->blessed  = flags&F_BLESSED ? 1 : 0;
     op->magical  = flags&F_MAGIC   ? 1 : 0;
     op->unpaid   = flags&F_UNPAID  ? 1 : 0;
     op->applied  = flags&F_APPLIED ? 1 : 0;
@@ -507,9 +524,10 @@ static void get_flags(item *op, uint16 flags) {
     set_flag_string(op);
 }
 
-void set_item_values(item *op, char *name, sint32 weight, uint16 face,
-                     uint16 flags, uint16 anim, uint16 animspeed,
-                     uint32 nrof, uint16 type) {
+void set_item_values(item *op, char *name, gint32 weight, guint16 face,
+                     guint16 flags, guint16 anim, guint16 animspeed,
+                     guint32 nrof, guint16 type)
+{
     int resort = 1;
 
     if (!op) {
@@ -543,7 +561,8 @@ void set_item_values(item *op, char *name, sint32 weight, uint16 face,
 
     if (op->nrof != nrof) {
         if (nrof != 1 ) {
-            sprintf(op->d_name, "%s %s", get_number(nrof), op->p_name);
+            snprintf(op->d_name, sizeof(op->d_name), "%s %s", get_number(nrof),
+                     op->p_name);
         } else {
             strcpy(op->d_name, op->s_name);
         }
@@ -574,9 +593,10 @@ void set_item_values(item *op, char *name, sint32 weight, uint16 face,
     item_event_item_changed(op);
 }
 
-void toggle_locked(item *op) {
+void toggle_locked(item *op)
+{
     SockList sl;
-    uint8 buf[MAX_BUF];
+    guint8 buf[MAX_BUF];
 
     if (op->env->tag == 0) {
         return; /* if item is on the ground, don't lock it */
@@ -591,9 +611,10 @@ void toggle_locked(item *op) {
     SockList_Send(&sl, csocket.fd);
 }
 
-void send_mark_obj(item *op) {
+void send_mark_obj(item *op)
+{
     SockList sl;
-    uint8 buf[MAX_BUF];
+    guint8 buf[MAX_BUF];
 
     if (op->env->tag == 0) {
         return; /* if item is on the ground, don't mark it */
@@ -607,12 +628,14 @@ void send_mark_obj(item *op) {
     SockList_Send(&sl, csocket.fd);
 }
 
-item *player_item (void) {
+item *player_item (void)
+{
     player = new_item();
     return player;
 }
 
-item *map_item (void) {
+item *map_item (void)
+{
     map = new_item();
     map->weight = -1;
     return map;
@@ -620,9 +643,8 @@ item *map_item (void) {
 
 /* Upates an item with new attributes. */
 void update_item(int tag, int loc, char *name, int weight, int face, int flags,
-                 int anim, int animspeed, uint32 nrof, int type) {
-    item *ip = locate_item(tag), *env = locate_item(loc);
-
+                 int anim, int animspeed, guint32 nrof, int type)
+{
     /* Need to do some special handling if this is the player that is
      * being updated.
      */
@@ -642,11 +664,17 @@ void update_item(int tag, int loc, char *name, int weight, int face, int flags,
         player->anim_speed = animspeed;
         player->nrof = nrof;
     } else {
+        item *ip = locate_item(tag), *env = locate_item(loc);
         if (ip && ip->env != env) {
+            // If item moved, it's easier to remove and re-add than to update
+            // everything that needs updating.
             remove_item(ip);
             ip = NULL;
         }
-        set_item_values(ip ? ip : create_new_item(env, tag), name, weight, face, flags,
+        if (ip == NULL) {
+            ip = create_new_item(env, tag);
+        }
+        set_item_values(ip, name, weight, face, flags,
                         anim, animspeed, nrof, type);
     }
 }
@@ -655,7 +683,8 @@ void update_item(int tag, int loc, char *name, int weight, int face, int flags,
  *  Prints players inventory, contain extra information for debugging purposes
  * This isn't pretty, but is only used for debugging, so it doesn't need to be.
  */
-void print_inventory(item *op) {
+void print_inventory(item *op)
+{
     char buf[MAX_BUF];
     char buf2[MAX_BUF];
     item *tmp;
@@ -688,7 +717,8 @@ void print_inventory(item *op) {
 }
 
 /* Check the objects, animate the ones as necessary */
-void animate_objects(void) {
+void animate_objects(void)
+{
     item *ip;
     int got_one = 0;
 
@@ -753,13 +783,15 @@ void animate_objects(void) {
     }
 }
 
-int can_write_spell_on(item* it) {
+int can_write_spell_on(item* it)
+{
     return (it->type == 661);
 }
 
-void inscribe_magical_scroll(item *scroll, Spell *spell) {
+void inscribe_magical_scroll(item *scroll, Spell *spell)
+{
     SockList sl;
-    uint8 buf[MAX_BUF];
+    guint8 buf[MAX_BUF];
 
     snprintf((char*)buf, sizeof(buf), "inscribe 0 %d %d", scroll->tag, spell->tag);
     script_monitor_str((char*)buf);
