@@ -1,36 +1,6 @@
-/* $Id: mapdata.h 12149 2009-08-20 02:11:28Z kbulgrien $ */
-/*
-    Crossfire client, a client program for the crossfire program.
-
-    Copyright (C) 2005 Mark Wedel & Crossfire Development Team
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-    The author can be reached via e-mail to crossfire-devel@real-time.com
-*/
-
-/**
- * @file common/mapdata.h
- *
- */
-
 #ifndef MAP_H
 #define MAP_H
 
-#include "client-types.h"
-
 /** The protocol supports 10 layers, so set MAXLAYERS accordingly.
  */
 #define MAXLAYERS 10
@@ -46,9 +16,9 @@
 #define MAP1_LAYERS 3
 
 struct MapCellLayer {
-    sint16 face;
-    sint8 size_x;
-    sint8 size_y;
+    gint16 face;
+    gint8 size_x;
+    gint8 size_y;
 
     /* Link into animation information.
      * animation is provided to us from the server in the map2 command.
@@ -57,10 +27,16 @@ struct MapCellLayer {
      *  by client.
      * animation_phase is current phase.
      */
-    sint16  animation;
-    uint8   animation_speed;
-    uint8   animation_left;
-    uint8   animation_phase;
+    gint16  animation;
+    guint8   animation_speed;
+    guint8   animation_left;
+    guint8   animation_phase;
+};
+
+struct MapCellTailLayer {
+    gint16 face;
+    gint8 size_x;
+    gint8 size_y;
 };
 
 /** The heads[] in the mapcell is used for single part objects
@@ -79,47 +55,40 @@ struct MapCellLayer {
 struct MapCell
 {
     struct MapCellLayer heads[MAXLAYERS];
-    struct MapCellLayer tails[MAXLAYERS];
-    uint16 smooth[MAXLAYERS];
-    uint8 darkness;         /* darkness: 0=fully illuminated, 255=pitch black */
-    uint8 need_update:1;    /* set if tile should be redrawn */
-    uint8 have_darkness:1;  /* set if darkness information was set */
-    uint8 need_resmooth:1;  /* same has need update but for smoothing only */
-    uint8 cleared:1;        /* If set, this is a fog cell. */
+    struct MapCellTailLayer tails[MAXLAYERS];
+    guint8 smooth[MAXLAYERS];
+    guint8 darkness;         /* darkness: 0=fully illuminated, 255=pitch black */
+    guint8 need_update:1;    /* set if tile should be redrawn */
+    guint8 have_darkness:1;  /* set if darkness information was set */
+    guint8 need_resmooth:1;  /* same has need update but for smoothing only */
+    guint8 cleared:1;        /* If set, this is a fog cell. */
 };
 
 struct Map
 {
-    /* Store size of map so we know if map_size has changed
-     * since the last time we allocated this;
-     */
-    int x;
-    int y;
-
-    struct MapCell **cells;
+    struct MapCell **_cells; //< data, access via mapdata_cells()
+    int width;  //< width of cells array
+    int height; //< height of cells array
 };
 
-
-extern struct Map the_map;
-
+struct MapCell *mapdata_cell(int x, int y);
+bool mapdata_contains(int x, int y);
+void mapdata_size(int *x, int *y);
+bool mapdata_can_smooth(int x, int y, int layer);
 
 /**
  * Initializes the module. Allocates memory for the_map. This functions must be
- * called before any other function is used.
- */
-void mapdata_init(void);
-
-/**
- * Resets all stored information.
- */
-void mapdata_reset(void);
-
-/**
- * Sets the current display size. Must be called whenever a new display size
+ * called before any other function is used, and whenever a new display size
  * was negotiated with the server.
  */
 void mapdata_set_size(int viewx, int viewy);
 
+/**
+ * Deallocate map data. Do not call functions other than mapdata_set_size()
+ * after calling mapdata_free().
+ */
+void mapdata_free(void);
+
 /**
  * Scrolls the map view. Must be called whenever a map_scroll command was
  * received from the server.
@@ -142,7 +111,21 @@ int mapdata_is_inside(int x, int y);
  * Returns the face to display at a given location. This function returns the
  * "head" information, i.e. the face information sent by the server.
  */
-sint16 mapdata_face(int x, int y, int layer);
+gint16 mapdata_face(int x, int y, int layer) __attribute__((deprecated));
+
+/**
+ * Return the face number of the pixmap in the given map cell and set the
+ * offset pointers to indicate where to correctly draw the face. Offsets are
+ * zero for single-tile maps and negative for multi-tile maps. This provides
+ * a consistent way to draw tiles no matter single or multi part.
+ * @param mx Virtual map x-coordinate
+ * @param my Virtual map y-coordinate
+ * @param layer Map layer number
+ * @param dx Pointer to store x-offset
+ * @param dy Pointer to store y-offset
+ * @return Pixmap face number, zero if the tile does not exist
+ */
+gint16 mapdata_face_info(int mx, int my, int layer, int *dx, int *dy);
 
 /**
  * Returns the face to display at a given location. This function returns the
@@ -156,6 +139,18 @@ sint16 mapdata_face(int x, int y, int layer);
  * contains obsolete (fog of war) big face information; this function detects
  * and clears such faces.
  */
-sint16 mapdata_bigface(int x, int y, int layer, int *ww, int *hh);
+gint16 mapdata_bigface(int x, int y, int layer, int *ww, int *hh);
+
+void mapdata_clear_space(int x, int y);
+void mapdata_set_check_space(int x, int y);
+void mapdata_set_darkness(int x, int y, int darkness);
+void mapdata_set_smooth(int x, int y, guint8 smooth, int layer);
+void mapdata_clear_old(int x, int y);
+void mapdata_set_face_layer(int x, int y, gint16 face, int layer);
+void mapdata_set_anim_layer(int x, int y, guint16 anim, guint8 anim_speed, int layer);
+gint16 mapdata_bigface_head(int x, int y, int layer, int *ww, int *hh);
+void mapdata_animation(void);
+
+extern PlayerPosition script_pos;
 
 #endif
