@@ -1,80 +1,42 @@
-const char * const rcsid_gtk2_image_c =
-    "$Id: image.c 12987 2010-04-27 03:50:58Z kbulgrien $";
 /*
-    Crossfire client, a client program for the crossfire program.
-
-    Copyright (C) 2005-2008,2010 Mark Wedel & Crossfire Development Team
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-    The author can be reached via e-mail to crossfire@metalforge.org
-*/
+ * Crossfire -- cooperative multi-player graphical RPG and adventure game
+ *
+ * Copyright (c) 1999-2013 Mark Wedel and the Crossfire Development Team
+ * Copyright (c) 1992 Frank Tore Johansen
+ *
+ * Crossfire is free software and comes with ABSOLUTELY NO WARRANTY. You are
+ * welcome to redistribute it under certain conditions. For details, see the
+ * 'LICENSE' and 'COPYING' files.
+ *
+ * The authors can be reached via e-mail to crossfire-devel@real-time.com
+ */
 
 /**
- * @file gtk-v2/src/image.c
+ * @file
  * Contains highlevel image related functions and mostly deals with the image
  * caching, processing the image commands from the server, etc.  It is
  * gtk-specific as it returns gtk pixmaps.
  */
 
-#include <config.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-#ifndef WIN32
-#include <unistd.h>
-#endif
-#include <png.h>
+#include "client.h"
 
-/* Pick up the gtk headers we need */
 #include <gtk/gtk.h>
-#include <glade/glade.h>
-#ifndef WIN32
-#include <gdk/gdkx.h>
-#else
-#include <gdk/gdkwin32.h>
-#endif
-#include <gdk/gdkkeysyms.h>
 
 #ifdef HAVE_SDL
-#include <SDL.h>
-#include <SDL_image.h>
+#include <SDL/SDL.h>
 #endif
 
-#include "client-types.h"
-#include "client.h"
 #include "image.h"
 #include "main.h"
-#include "mapdata.h"
 #include "gtk2proto.h"
 
 extern GtkWidget *window_root; /**< In main.c */
 int image_size=DEFAULT_IMAGE_SIZE;
 
-struct {
-    char    *name;
-    uint32  checksum;
-    uint8   *png_data;
-    uint32  width, height;
-} private_cache[MAXPIXMAPNUM];
-
 #define BPP 4
 
 PixmapInfo *pixmaps[MAXPIXMAPNUM];
 
-int last_face_num=0;
-
 /* Do we have new images to display? */
 int have_new_image=0;
 
@@ -94,9 +56,9 @@ int have_new_image=0;
 
 #define MAX_ICON_SPACES     10
 static const int icon_rescale_factor[MAX_ICON_SPACES] = {
-100, 100,           80 /* 2 = 160 */,   60 /* 3 = 180 */,
-50 /* 4 = 200 */,   45 /* 5 = 225 */,   40 /* 6 = 240 */,
-35 /* 7 = 259 */,   35 /* 8 = 280 */,   33 /* 9 = 300 */
+    100, 100,           80 /* 2 = 160 */,   60 /* 3 = 180 */,
+    50 /* 4 = 200 */,   45 /* 5 = 225 */,   40 /* 6 = 240 */,
+    35 /* 7 = 259 */,   35 /* 8 = 280 */,   33 /* 9 = 300 */
 };
 
 /******************************************************************************
@@ -122,17 +84,10 @@ typedef struct Keys {
 
 /**
  * Helper function to make the code more readable
- *
- * @param data
- * @param pi
- * @param pixmap_num
  */
-static void create_icon_image(uint8 *data, PixmapInfo *pi, int pixmap_num)
-{
+static void create_icon_image(guint8 *data, PixmapInfo *pi) {
     pi->icon_mask = NULL;
-    if (rgba_to_gdkpixbuf(data, pi->icon_width, pi->icon_height,
-                (GdkPixbuf**)&pi->icon_image))
-                    LOG (LOG_ERROR,"gtk-v2::create_icon_image","Unable to create scaled image, dest num = %d\n", pixmap_num);
+    pi->icon_image = rgba_to_gdkpixbuf(data, pi->icon_width, pi->icon_height);
 }
 
 /**
@@ -141,51 +96,55 @@ static void create_icon_image(uint8 *data, PixmapInfo *pi, int pixmap_num)
  * @param data
  * @param pi
  */
-static void create_map_image(uint8 *data, PixmapInfo *pi)
-{
+static void create_map_image(guint8 *data, PixmapInfo *pi) {
     pi->map_image = NULL;
     pi->map_mask = NULL;
 
     if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_SDL) {
 #if defined(HAVE_SDL)
-        int i;
+        int i, width = pi->map_width, height = pi->map_height;
         SDL_Surface *fog;
-        uint32 g,*p;
-        uint8 *l;
+        guint32 g,*p;
+        guint8 *l, *scaled;
+        if (use_config[CONFIG_MAPSCALE] != 100)
+            scaled = rescale_rgba_data(data, &width, &height, use_config[CONFIG_MAPSCALE]);
+        else
+            scaled = data;
+        pi->map_width = width, pi->map_height = height;
 
 #if SDL_BYTEORDER == SDL_LIL_ENDIAN
-        pi->map_image = SDL_CreateRGBSurfaceFrom(data, pi->map_width,
-                pi->map_height, 32, pi->map_width * 4,  0xff,
+        pi->map_image = SDL_CreateRGBSurfaceFrom(scaled, width,
+                        height, 32, width * 4,  0xff,
                         0xff00, 0xff0000, 0xff000000);
 
         fog = SDL_CreateRGBSurface(SDL_SRCALPHA | SDL_HWSURFACE,
-                pi->map_width,  pi->map_height, 32, 0xff,
-                        0xff00, 0xff0000, 0xff000000);
+                                   width,  height, 32, 0xff,
+                                   0xff00, 0xff0000, 0xff000000);
         SDL_LockSurface(fog);
 
-        for (i=0; i < pi->map_width * pi->map_height; i++) {
-            l = (uint8 *) (data + i*4);
+        for (i=0; i < width * height; i++) {
+            l = (guint8 *) (scaled + i*4);
 #if 1
             g = MAX(*l, *(l+1));
             g = MAX(g, *(l+2));
 #else
             g = ( *l +  *(l+1) + *(l+2)) / 3;
 #endif
-            p = (uint32*) fog->pixels + i;
+            p = (guint32*) fog->pixels + i;
             *p = g | (g << 8) | (g << 16) | (*(l + 3) << 24);
         }
 
         SDL_UnlockSurface(fog);
         pi->fog_image = fog;
-    #else
+#else
         /* Big endian */
-        pi->map_image = SDL_CreateRGBSurfaceFrom(data, pi->map_width,
-                pi->map_height, 32, pi->map_width * 4,  0xff000000,
+        pi->map_image = SDL_CreateRGBSurfaceFrom(scaled, width,
+                        height, 32, width * 4,  0xff000000,
                         0xff0000, 0xff00, 0xff);
 
         fog = SDL_CreateRGBSurface(SDL_SRCALPHA | SDL_HWSURFACE,
-                pi->map_width,  pi->map_height, 32, 0xff000000,
-                        0xff0000, 0xff00, 0xff);
+                                   width,  height, 32, 0xff000000,
+                                   0xff0000, 0xff00, 0xff);
         SDL_LockSurface(fog);
 
         /*
@@ -193,49 +152,52 @@ static void create_map_image(uint8 *data, PixmapInfo *pi)
          * as my recollection is that the png data would be in the same order,
          * just the bytes for it to go on the screen are reversed.
          */
-        for (i=0; i < pi->map_width * pi->map_height; i++) {
-            l = (uint8 *) (data + i*4);
+        for (i=0; i < width * height; i++) {
+            l = (guint8 *) (scaled + i*4);
 #if 1
             g = MAX(*l, *(l+1));
             g = MAX(g, *(l+2));
 #else
             g = ( *l +  *(l+1) + *(l+2)) / 3;
 #endif
-            p = (uint32*) fog->pixels + i;
+            p = (guint32*) fog->pixels + i;
             *p = (g << 8) | (g << 16) | (g << 24) | *(l + 3);
         }
 
-        for (i=0; i < pi->map_width * pi->map_height; i+= 4) {
-            uint32 *tmp;
+        for (i=0; i < width * ny; i+= 4) {
+            guint32 *tmp;
 
             /*
              * The pointer arithemtic below looks suspicious, but it is a patch
              * that is submitted, so just putting it in as submitted.  MSW
              * 2004-05-11
              */
-            p = (uint32*) (fog->pixels + i);
+            p = (guint32*) (fog->pixels + i);
             g = ( ((*p >> 24) & 0xff)  + ((*p >> 16) & 0xff) + ((*p >> 8) & 0xff)) / 3;
-            tmp = (uint32*) fog->pixels + i;
+            tmp = (guint32*) fog->pixels + i;
             *tmp = (g << 24) | (g << 16) | (g << 8) | (*p & 0xff);
         }
 
         SDL_UnlockSurface(fog);
         pi->fog_image = fog;
-    #endif
+#endif
 
 #endif
-    }
-    else if (use_config[CONFIG_DISPLAYMODE] == CFG_DM_OPENGL){
+    } else if (use_config[CONFIG_DISPLAYMODE] == CFG_DM_OPENGL) {
 #ifdef HAVE_OPENGL
         create_opengl_map_image(data, pi);
 #endif
+    } else if (use_config[CONFIG_DISPLAYMODE] == CFG_DM_PIXMAP) {
+        pi->map_image = rgba_to_cairo_surface(data, pi->map_width, pi->map_height);
     }
+}
 
-    else if (use_config[CONFIG_DISPLAYMODE] == CFG_DM_PIXMAP){
-        rgba_to_gdkpixmap(window_root->window, data, pi->map_width, pi->map_height,
-                (GdkPixmap**)&pi->map_image, (GdkBitmap**)&pi->map_mask,
-                gtk_widget_get_colormap(window_root));
-    }
+/**
+ * Wrapper for accessing outside this file.
+ */
+void do_new_image(guint8 *data, PixmapInfo *pi) {
+    create_icon_image(data, pi);
+    create_map_image(data, pi);
 }
 
 /**
@@ -245,38 +207,42 @@ static void create_map_image(uint8 *data, PixmapInfo *pi)
  */
 static void free_pixmap(PixmapInfo *pi)
 {
-    if (pi->icon_image) g_object_unref(pi->icon_image);
-    if (pi->icon_mask) g_object_unref(pi->icon_mask);
-    if (pi->map_mask) gdk_pixmap_unref(pi->map_mask);
-        if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_SDL) {
+    if (pi->icon_image) {
+        g_object_unref(pi->icon_image);
+    }
+    if (pi->icon_mask) {
+        g_object_unref(pi->icon_mask);
+    }
+    if (pi->map_mask) {
+        g_object_unref(pi->map_mask);
+    }
+    if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_SDL) {
 #ifdef HAVE_SDL
-            if (pi->map_image) {
-                SDL_FreeSurface(pi->map_image);
-                free(((SDL_Surface*)pi->map_image)->pixels);
-                SDL_FreeSurface(pi->fog_image);
-                /*
-                 * Minor memory leak here - SDL_FreeSurface() frees the pixel
-                 * data _unless_ SDL_CreateRGBSurfaceFrom() was used to create
-                 * the surface.  SDL_CreateRGBSurfaceFrom() is used to create
-                 * the map data, which is why we need the free there.  The
-                 * reason this is a minor memory leak is because
-                 * SDL_CreateRGBSurfaceFrom() is used to create the question
-                 * mark image, and without this free, that data is not freed.
-                 * However, with this, client crashes after disconnecting from
-                 * server with double free.
-                 */
-    /*          free(((SDL_Surface*)pi->fog_image)->pixels);*/
-            }
-#endif
-        }
-        else if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_OPENGL) {
-#ifdef HAVE_OPENGL
-            opengl_free_pixmap(pi);
-#endif
-        }
-    else if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_PIXMAP) {
         if (pi->map_image) {
-            gdk_pixmap_unref(pi->map_image);
+            g_free(((SDL_Surface*)pi->map_image)->pixels);
+            SDL_FreeSurface(pi->map_image);
+            SDL_FreeSurface(pi->fog_image);
+            /*
+             * Minor memory leak here - SDL_FreeSurface() frees the pixel
+             * data _unless_ SDL_CreateRGBSurfaceFrom() was used to create
+             * the surface.  SDL_CreateRGBSurfaceFrom() is used to create
+             * the map data, which is why we need the free there.  The
+             * reason this is a minor memory leak is because
+             * SDL_CreateRGBSurfaceFrom() is used to create the question
+             * mark image, and without this free, that data is not freed.
+             * However, with this, client crashes after disconnecting from
+             * server with double free.
+             */
+            /*          free(((SDL_Surface*)pi->fog_image)->pixels);*/
+        }
+#endif
+    } else if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_OPENGL) {
+#ifdef HAVE_OPENGL
+        opengl_free_pixmap(pi);
+#endif
+    } else if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_PIXMAP) {
+        if (pi->map_image) {
+            cairo_surface_destroy(pi->map_image);
         }
     }
 }
@@ -294,14 +260,14 @@ static void free_pixmap(PixmapInfo *pi)
  *
  * @return 1 on failure.
  */
-int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *rgba_data, int width, int height)
-{
+int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num,
+        guint8 *rgba_data, int width, int height) {
     int nx, ny, iscale, factor;
-    uint8 *png_tmp;
     PixmapInfo  *pi;
 
-    if (pixmap_num <= 0 || pixmap_num >= MAXPIXMAPNUM)
+    if (pixmap_num <= 0 || pixmap_num >= MAXPIXMAPNUM) {
         return 1;
+    }
 
     if (pixmaps[pixmap_num] != pixmaps[0]) {
         /* As per bug 2938906, one can see image corruption when switching between
@@ -320,10 +286,10 @@ int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *r
          *    on the second server, causing this routine to be called.
          */
 
-         if (!use_config[CONFIG_CACHE]) {
-             free_pixmap(pixmaps[pixmap_num]);
-             free(pixmaps[pixmap_num]);
-         }
+        if (!use_config[CONFIG_CACHE]) {
+            free_pixmap(pixmaps[pixmap_num]);
+            free(pixmaps[pixmap_num]);
+        }
         pixmaps[pixmap_num] = pixmaps[0];
     }
 
@@ -339,12 +305,20 @@ int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *r
         int ts = 100;
 
         factor = width / DEFAULT_IMAGE_SIZE;
-        if (factor >= MAX_ICON_SPACES) factor = MAX_ICON_SPACES - 1;
-        if (icon_rescale_factor[factor] < ts) ts = icon_rescale_factor[factor];
+        if (factor >= MAX_ICON_SPACES) {
+            factor = MAX_ICON_SPACES - 1;
+        }
+        if (icon_rescale_factor[factor] < ts) {
+            ts = icon_rescale_factor[factor];
+        }
 
         factor = height / DEFAULT_IMAGE_SIZE;
-        if (factor >= MAX_ICON_SPACES) factor = MAX_ICON_SPACES - 1;
-        if (icon_rescale_factor[factor] < ts) ts = icon_rescale_factor[factor];
+        if (factor >= MAX_ICON_SPACES) {
+            factor = MAX_ICON_SPACES - 1;
+        }
+        if (icon_rescale_factor[factor] < ts) {
+            ts = icon_rescale_factor[factor];
+        }
 
         iscale = ts * use_config[CONFIG_ICONSCALE] / 100;
     }
@@ -353,16 +327,15 @@ int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *r
     if (iscale != 100) {
         nx=width;
         ny=height;
-        png_tmp = rescale_rgba_data(rgba_data, &nx, &ny, iscale);
+        guint8 *png_tmp = rescale_rgba_data(rgba_data, &nx, &ny, iscale);
         pi->icon_width = nx;
         pi->icon_height = ny;
-        create_icon_image(png_tmp, pi, pixmap_num);
+        create_icon_image(png_tmp, pi);
         free(png_tmp);
-    }
-    else {
+    } else {
         pi->icon_width = width;
         pi->icon_height = height;
-        create_icon_image(rgba_data, pi, pixmap_num);
+        create_icon_image(rgba_data, pi);
     }
 
     /*
@@ -370,31 +343,20 @@ int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *r
      * more intelligent, but this should not be called too often, and this
      * keeps the code simpler.
      */
-    if (use_config[CONFIG_MAPSCALE] != 100) {
-        nx=width;
-        ny=height;
-        png_tmp = rescale_rgba_data(rgba_data, &nx, &ny, use_config[CONFIG_MAPSCALE]);
-        pi->map_width = nx;
-        pi->map_height = ny;
-        create_map_image(png_tmp, pi);
-        /*
-         * pixmap mode and opengl don't need the rgba data after they have
-         * created the image, so we can free it.  SDL uses the raw rgba data,
-         * so it can't be freed.
-         */
-        if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_PIXMAP ||
-            use_config[CONFIG_DISPLAYMODE]==CFG_DM_OPENGL) free(png_tmp);
-    } else {
+    guint8 *png_tmp;
+
+    {
         pi->map_width = width;
         pi->map_height = height;
         /*
          * If using SDL mode, a copy of the rgba data needs to be stored away.
          */
         if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_SDL) {
-            png_tmp = malloc(width * height * BPP);
+            png_tmp = g_malloc(width * height * BPP);
             memcpy(png_tmp, rgba_data, width * height * BPP);
-        } else
+        } else {
             png_tmp = rgba_data;
+        }
         create_map_image(png_tmp, pi);
     }
     /*
@@ -411,8 +373,9 @@ int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *r
         ce->image_data = pi;
     }
     pixmaps[pixmap_num] = pi;
-    if (use_config[CONFIG_CACHE])
+    if (use_config[CONFIG_CACHE]) {
         have_new_image++;
+    }
 
     return 0;
 }
@@ -423,7 +386,7 @@ int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *r
  * @param face
  * @param smooth_face
  */
-void addsmooth(uint16 face, uint16 smooth_face)
+void addsmooth(guint16 face, guint16 smooth_face)
 {
     pixmaps[face]->smooth_face = smooth_face;
 }
@@ -468,9 +431,7 @@ void reset_image_data(void)
     }
 }
 
-static GtkWidget     *pbar=NULL;
-static GtkWidget     *pbar_window=NULL;
-static GtkAdjustment *padj=NULL;
+static GtkWidget *pbar, *pbar_window;
 
 /**
  * Draws a status bar showing where we our in terms of downloading all the
@@ -483,43 +444,28 @@ static GtkAdjustment *padj=NULL;
  * @param end
  * @param total The total number of images.
  */
-void image_update_download_status(int start, int end, int total)
-{
+void image_update_download_status(int start, int end, int total) {
     int x, y, wx, wy, w, h;
 
     if (start == 1) {
-        padj = (GtkAdjustment*) gtk_adjustment_new (0, 1, total, 0, 0, 0);
-
-        pbar = gtk_progress_bar_new_with_adjustment(padj);
-        gtk_progress_set_format_string(GTK_PROGRESS(pbar), "Downloading image %v of %u (%p%% complete)");
-        gtk_progress_bar_set_bar_style(GTK_PROGRESS_BAR(pbar), GTK_PROGRESS_CONTINUOUS);
-        gtk_progress_set_show_text(GTK_PROGRESS(pbar), TRUE);
+        pbar = gtk_progress_bar_new();
         get_window_coord(window_root, &x,&y, &wx,&wy,&w,&h);
 
         pbar_window = gtk_window_new(GTK_WINDOW_POPUP);
-        gtk_window_set_policy(GTK_WINDOW(pbar_window), TRUE, TRUE, FALSE);
         gtk_window_set_transient_for(GTK_WINDOW(pbar_window), GTK_WINDOW (window_root));
-        /*
-         * We more or less want this window centered on the main crossfire
-         * window, and not necessarily centered on the screen or in the upper
-         * left corner.
-         */
-        gtk_widget_set_uposition(pbar_window, (wx + w)/2, (wy + h) / 2);
 
         gtk_container_add(GTK_CONTAINER(pbar_window), pbar);
         gtk_widget_show(pbar);
         gtk_widget_show(pbar_window);
-    }
-    if (start == total) {
+    } else if (start == total) {
         gtk_widget_destroy(pbar_window);
         pbar = NULL;
         pbar_window = NULL;
-        padj = NULL;
         return;
     }
 
-    gtk_progress_set_value(GTK_PROGRESS(pbar), start);
-    while ( gtk_events_pending() ) {
+    gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(pbar), (float)start / end);
+    while (gtk_events_pending()) {
         gtk_main_iteration();
     }
 }
@@ -530,7 +476,7 @@ void image_update_download_status(int start, int end, int total)
  * @param w
  * @param h
  */
-void get_map_image_size(int face, uint8 *w, uint8 *h)
+void get_map_image_size(int face, guint8 *w, guint8 *h)
 {
     /* We want to calculate the number of spaces this image
      * uses it.  By adding the image size but substracting one,
@@ -543,8 +489,9 @@ void get_map_image_size(int face, uint8 *w, uint8 *h)
         *w = 1;
         *h = 1;
     } else {
-        *w = (pixmaps[face]->map_width + map_image_size - 1)/ map_image_size;
-        *h = (pixmaps[face]->map_height + map_image_size - 1)/ map_image_size;
+        const int scaled_image_size = map_image_size * use_config[CONFIG_MAPSCALE] / 100;
+        *w = (pixmaps[face]->map_width + scaled_image_size - 1)/ scaled_image_size;
+        *h = (pixmaps[face]->map_height + scaled_image_size - 1)/ scaled_image_size;
     }
 }
 
@@ -569,15 +516,10 @@ void init_image_cache_data(void)
     GtkStyle *style;
 #include "../../pixmaps/question.xpm"
 
-
-    LOG(LOG_INFO,"gtk-v2::init_image_cache_data","Init Image Cache");
-
     style = gtk_widget_get_style(window_root);
-    pixmaps[0] = malloc(sizeof(PixmapInfo));
-    pixmaps[0]->icon_image = gdk_pixmap_create_from_xpm_d(window_root->window,
-                                                        (GdkBitmap**)&pixmaps[0]->icon_mask,
-                                                        &style->bg[GTK_STATE_NORMAL],
-                                                        (gchar **)question_xpm);
+    pixmaps[0] = g_new(PixmapInfo, 1);
+    pixmaps[0]->icon_image =
+        gdk_pixbuf_new_from_xpm_data((const gchar **)question_xpm);
 #ifdef HAVE_SDL
     if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_SDL) {
         /*
@@ -586,24 +528,22 @@ void init_image_cache_data(void)
          */
 #include "../../pixmaps/question.sdl"
         pixmaps[0]->map_image = SDL_CreateRGBSurfaceFrom(question_sdl,
-                32, 32, 1, 4, 1, 1, 1, 1);
+                                32, 32, 1, 4, 1, 1, 1, 1);
         SDL_SetAlpha(pixmaps[0]->map_image, SDL_SRCALPHA, 70);
         pixmaps[0]->fog_image = SDL_CreateRGBSurfaceFrom(question_sdl,
-                32, 32, 1, 4, 1, 1, 1, 1);
+                                32, 32, 1, 4, 1, 1, 1, 1);
         SDL_SetAlpha(pixmaps[0]->fog_image, SDL_SRCALPHA, 70);
-    }
-    else
+    } else
 #endif
-    if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_PIXMAP)
-    {
-        pixmaps[0]->map_image =  pixmaps[0]->icon_image;
-        pixmaps[0]->fog_image =  pixmaps[0]->icon_image;
-        pixmaps[0]->map_mask =  pixmaps[0]->icon_mask;
-    }
+        if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_PIXMAP) {
+            pixmaps[0]->map_image =  pixmaps[0]->icon_image;
+            pixmaps[0]->fog_image =  pixmaps[0]->icon_image;
+            pixmaps[0]->map_mask =  pixmaps[0]->icon_mask;
+        }
 #ifdef HAVE_OPENGL
-    else if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_OPENGL) {
-        create_opengl_question_mark();
-    }
+        else if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_OPENGL) {
+            create_opengl_question_mark();
+        }
 #endif
 
     pixmaps[0]->icon_width = pixmaps[0]->icon_height = pixmaps[0]->map_width = pixmaps[0]->map_height = map_image_size;
