@@ -1,62 +1,42 @@
-const char * const rcsid_gtk2_opengl_c =
-    "$Id: opengl.c 12987 2010-04-27 03:50:58Z kbulgrien $";
-
 /*
-    Crossfire client, a client program for the crossfire program.
-
-    Copyright (C) 2005,2010 Mark Wedel & Crossfire Development Team
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-    The author can be reached via e-mail to crossfire@metalforge.org
-*/
+ * Crossfire -- cooperative multi-player graphical RPG and adventure game
+ *
+ * Copyright (c) 1999-2013 Mark Wedel and the Crossfire Development Team
+ * Copyright (c) 1992 Frank Tore Johansen
+ *
+ * Crossfire is free software and comes with ABSOLUTELY NO WARRANTY. You are
+ * welcome to redistribute it under certain conditions. For details, see the
+ * 'LICENSE' and 'COPYING' files.
+ *
+ * The authors can be reached via e-mail to crossfire-devel@real-time.com
+ */
 
 /**
- * @file gtk-v2/src/opengl.c
+ * @file
  * Implements an opengl version of the map renderer.  I've tried to keep this
  * platform generic, but there are just some things that must be tied to the
  * window system is is using, namely, window creation and flipping the data
  * buffers.  For that, on X, we use to use glx - MSW 2005-03-12
- *
- * NOTE: Using dmalloc with opengl causes problems - it gets an invalid
- * allocation - I haven't dug through it, but my guess is that some internal
- * opengl/glx routine is doing something like a malloc(0) which dmalloc
- * catches.
  */
 
-#include <config.h>
+#include "client.h"
 
 #ifdef HAVE_OPENGL
 
-#include <client-types.h>
-
+#include <errno.h>
+#include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
+
 #ifndef WIN32
 #include <gdk/gdkx.h>
 #else
 #include <windows.h>
 #include <gdk/gdkwin32.h>
 #endif
-#include <gdk/gdkkeysyms.h>
 
-#include <client.h>
-#include "main.h"
 #include "image.h"
+#include "main.h"
 #include "mapdata.h"
-
 #include "gtk2proto.h"
 
 /* Start of Open GL includes */
@@ -66,8 +46,6 @@ const char * const rcsid_gtk2_opengl_c =
 #include <GL/glx.h>
 #endif
 
-extern int time_map_redraw;
-
 #ifndef WIN32
 static Display  *display;       /* X display & window for glx buffer swapping */
 static Window   window;
@@ -95,16 +73,16 @@ static void init_opengl_common(void)
     glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
     glClearDepth(1.0f);
 
-    #ifndef WIN32
+#ifndef WIN32
     glViewport(0, 0, (float)width, (float)height);
-    #else
+#else
     /*
      * There is a bug somewhere that causes the viewport to be shifted up by
      * 25-MAPHEIGHT tiles when run in Windows.  Don't know yet what causes
      * this, but this is a bad hack to fix it.
      */
     glViewport(0, (use_config[CONFIG_MAPHEIGHT]-25)*32, (float)width, (float)height);
-    #endif
+#endif
 
     glMatrixMode(GL_PROJECTION);
     glLoadIdentity();
@@ -131,17 +109,17 @@ void init_glx_opengl(GtkWidget* drawingarea)
     GLXContext  ctx;
     XVisualInfo *vi;
     int attrListDbl[] = { GLX_RGBA, GLX_DOUBLEBUFFER,
-        GLX_RED_SIZE, 4,
-        GLX_GREEN_SIZE, 4,
-        GLX_BLUE_SIZE, 4,
-        GLX_ALPHA_SIZE, 4,
-        GLX_DEPTH_SIZE, 16,
-        None };
+                          GLX_RED_SIZE, 4,
+                          GLX_GREEN_SIZE, 4,
+                          GLX_BLUE_SIZE, 4,
+                          GLX_ALPHA_SIZE, 4,
+                          GLX_DEPTH_SIZE, 16,
+                          None
+                        };
     XSetWindowAttributes attr;
-    Visual *v;
 
     /* Need to tuck these away, because they are needed for glXSwappBuffers() */
-    display = GDK_WINDOW_XDISPLAY(drawingarea->window);
+    display = GDK_WINDOW_XDISPLAY(gtk_widget_get_window(drawingarea));
     vi = glXChooseVisual(display,
                          gdk_x11_get_default_screen (), attrListDbl);
 
@@ -155,14 +133,14 @@ void init_glx_opengl(GtkWidget* drawingarea)
      * create a colormap if using a different visual or we get a BadMatch
      * error.
      */
-    v = DefaultVisual(display, gdk_x11_get_default_screen ());
-    attr.colormap= XCreateColormap(display, GDK_WINDOW_XID(drawingarea->window),
+    DefaultVisual(display, gdk_x11_get_default_screen ());
+    attr.colormap= XCreateColormap(display, GDK_WINDOW_XID(gtk_widget_get_window(drawingarea)),
                                    vi->visual, AllocNone);
 
-    window = XCreateWindow(display, GDK_WINDOW_XID(drawingarea->window),
-                0, 0, width, height, 0,
+    window = XCreateWindow(display, GDK_WINDOW_XID(gtk_widget_get_window(drawingarea)),
+                           0, 0, width, height, 0,
                            vi->depth,
-                        InputOutput,
+                           InputOutput,
                            vi->visual,
                            CWColormap, &attr);
 
@@ -178,10 +156,11 @@ void init_glx_opengl(GtkWidget* drawingarea)
         LOG(LOG_ERROR,"gtk-v2::init_glx_opengl", "Could not set opengl context!\n");
         exit(1);
     }
-    if (glXIsDirect(display, ctx))
+    if (glXIsDirect(display, ctx)) {
         LOG(LOG_INFO,"gtk-v2::init_glx_opengl", "Direct rendering is available!\n");
-    else
+    } else {
         LOG(LOG_INFO,"gtk-v2::init_glx_opengl", "Direct rendering is not available!\n");
+    }
 
 }
 #endif /* #ifndef WIN32 */
@@ -221,7 +200,7 @@ void init_wgl_opengl(GtkWidget* drawingarea)
     width = drawingarea->allocation.width;
     height = drawingarea->allocation.height;
 
-    dctx = GetDC(GDK_WINDOW_HWND(drawingarea->window));
+    dctx = GetDC(GDK_WINDOW_HWND(gtk_widget_get_window(drawingarea)));
     devicecontext = dctx;
 
     /* Get the closest matching pixel format to what we specified and set it */
@@ -242,11 +221,11 @@ void init_wgl_opengl(GtkWidget* drawingarea)
 void init_opengl(GtkWidget* drawingarea)
 {
 
-    #ifndef WIN32
+#ifndef WIN32
     init_glx_opengl(drawingarea);
-    #else
+#else
     init_wgl_opengl(drawingarea);
-    #endif
+#endif
     init_opengl_common();
 }
 
@@ -259,7 +238,7 @@ void init_opengl(GtkWidget* drawingarea)
  * logic for final row/column).  That is +1 value.  but the last row also has
  * the right/bottom side vertices, and that is where the other +1 comes from
  */
-static uint16 map_darkness[(MAP_MAX_SIZE+2)*2][(MAP_MAX_SIZE+2)*2];
+static guint16 map_darkness[(MAP_MAX_SIZE+2)*2][(MAP_MAX_SIZE+2)*2];
 
 /*
  * This is darkness to use if we have no darkness information.  0 makes sense
@@ -292,9 +271,11 @@ static void opengl_light_space(int x, int y, int mx, int my)
 {
     if (use_config[CONFIG_DARKNESS] == CFG_LT_TILE) {
         /* If we don't have darkness, or it isn't dark, don't do anything */
-        if (!the_map.cells[mx][my].have_darkness || the_map.cells[mx][my].darkness==0) return;
+        if (!mapdata_cell(mx, my)->have_darkness || mapdata_cell(mx, my)->darkness==0) {
+            return;
+        }
 
-        glColor4ub(0, 0, 0,  the_map.cells[mx][my].darkness);
+        glColor4ub(0, 0, 0,  mapdata_cell(mx, my)->darkness);
         glBegin(GL_QUADS);
         glVertex3i(x * map_image_size, y * map_image_size, 0);
         glVertex3i((x+1) * map_image_size, y * map_image_size, 0);
@@ -376,21 +357,21 @@ static void opengl_light_space(int x, int y, int mx, int my)
  * Some basics.  dx, dy are coordinate pairs for offsets. bweights and cweights
  * are bitmasks that determine the face to draw (or'd together)
  */
-static int dx[8]={0,1,1,1,0,-1,-1,-1};
-static int dy[8]={-1,-1,0,1,1,1,0,-1};
+static int dx[8]= {0,1,1,1,0,-1,-1,-1};
+static int dy[8]= {-1,-1,0,1,1,1,0,-1};
 
-static int bweights[8]={2,0,4,0,8,0,1,0};
-static int cweights[8]={0,2,0,4,0,8,0,1};
-static int bc_exclude[8]={
-                 1+2,/*north exclude northwest (bit0) and northeast(bit1)*/
-                 0,
-                 2+4,/*east exclude northeast and southeast*/
-                 0,
-                 4+8,/*and so on*/
-                 0,
-                 8+1,
-                 0
-                };
+static int bweights[8]= {2,0,4,0,8,0,1,0};
+static int cweights[8]= {0,2,0,4,0,8,0,1};
+static int bc_exclude[8]= {
+    1+2,/*north exclude northwest (bit0) and northeast(bit1)*/
+    0,
+    2+4,/*east exclude northeast and southeast*/
+    0,
+    4+8,/*and so on*/
+    0,
+    8+1,
+    0
+};
 
 /*
  * Vertices are floats.  This sets the value appropriately for us to multiply
@@ -409,26 +390,26 @@ static int bc_exclude[8]={
  * @param my Coordinate of square to smooth on.
  * @param layer Layer to examine (we smooth only one layer at a time).
  */
-static void drawsmooth_opengl (int x, int y, int mx, int my, int layer) {
-    int partdone[8]={0,0,0,0,0,0,0,0}, slevels[8], sfaces[8], i,
-        weight,weightC, emx,emy, smoothface, dosmooth, lowest, havesmooth;
+static void drawsmooth_opengl (int x, int y, int mx, int my, int layer)
+{
+    int partdone[8]= {0,0,0,0,0,0,0,0}, slevels[8], sfaces[8], i,
+                     weight,weightC, emx,emy, smoothface, dosmooth, lowest, havesmooth;
 
     dosmooth=0;
-    for (i=0;i<8;i++){
+    for (i=0; i<8; i++) {
         emx=mx+dx[i];
         emy=my+dy[i];
 
-        if ( (emx<0) || (emy<0) || (emx >= the_map.x) || (emy >= the_map.y)){
+        if (!mapdata_contains(emx, emy)) {
             slevels[i]=0;
             sfaces[i]=0; /*black picture*/
-        }
-        else if (the_map.cells[emx][emy].smooth[layer]<=the_map.cells[mx][my].smooth[layer] ||
-            the_map.cells[emx][emy].heads[layer].face == 0){
+        } else if (mapdata_cell(emx, emy)->smooth[layer]<=mapdata_cell(mx, my)->smooth[layer] ||
+                   mapdata_cell(emx, emy)->heads[layer].face == 0) {
             slevels[i]=0;
             sfaces[i]=0; /*black picture*/
-        } else{
-            slevels[i]=the_map.cells[emx][emy].smooth[layer];
-            sfaces[i]=pixmaps[the_map.cells[emx][emy].heads[layer].face]->smooth_face;
+        } else {
+            slevels[i]=mapdata_cell(emx, emy)->smooth[layer];
+            sfaces[i]=pixmaps[mapdata_cell(emx, emy)->heads[layer].face]->smooth_face;
             dosmooth++;
         }
     }
@@ -444,31 +425,33 @@ static void drawsmooth_opengl (int x, int y, int mx, int my, int layer) {
 
     while (havesmooth < dosmooth) {
         lowest=-1;
-        for (i=0;i<8;i++){
-            if ( (slevels[i]>0) && (!partdone[i]) && ((lowest<0) || (slevels[i]<slevels[lowest])))
+        for (i=0; i<8; i++) {
+            if ( (slevels[i]>0) && (!partdone[i]) && ((lowest<0) || (slevels[i]<slevels[lowest]))) {
                 lowest=i;
+            }
+        }
+        if (lowest<0) {
+            break;    /*no more smooth to do on this square*/
         }
-        if (lowest<0)
-            break;   /*no more smooth to do on this square*/
 
         /* The weight values is a bitmask that determines what image we draw */
         weight=0;
         weightC=15; /*works in backward. remove where there is nothing*/
 
-        for (i=0;i<8;i++){ /*check all nearby squares*/
+        for (i=0; i<8; i++) { /*check all nearby squares*/
             if (slevels[i]==slevels[lowest] && sfaces[i] == sfaces[lowest]) {
                 partdone[i]=1;
                 weight=weight+bweights[i];
                 weightC&=~bc_exclude[i];
                 havesmooth++;
-            } else{
+            } else {
                 /*must rmove the weight of a corner if not in smoothing*/
                 weightC&=~cweights[i];
             }
         }
 
         smoothface=sfaces[lowest];
-        if (smoothface<=0){
+        if (smoothface<=0) {
             continue;  /*picture for smoothing not yet available*/
         }
 
@@ -479,13 +462,15 @@ static void drawsmooth_opengl (int x, int y, int mx, int my, int layer) {
          * and (32*weightC,32)
          */
 
-        if ( (!pixmaps[smoothface]->map_texture) || (pixmaps[smoothface] == pixmaps[0]))
-            continue;   /*don't have the picture associated*/
+        if ( (!pixmaps[smoothface]->map_texture) || (pixmaps[smoothface] == pixmaps[0])) {
+            continue;    /*don't have the picture associated*/
+        }
 
-        if (the_map.cells[mx][my].cleared)
+        if (mapdata_cell(mx, my)->cleared) {
             glBindTexture(GL_TEXTURE_2D, pixmaps[smoothface]->fog_texture);
-        else
+        } else {
             glBindTexture(GL_TEXTURE_2D, pixmaps[smoothface]->map_texture);
+        }
 
         /*
          * The values of 0.0f and 0.5f are hardcoded, but as of now, it is a
@@ -543,8 +528,9 @@ static void draw_smoothing(int layer)
             mx = x + pl_pos.x;
             my = y + pl_pos.y;
 
-            if (CAN_SMOOTH(the_map.cells[mx][my],layer))
+            if (mapdata_can_smooth(mx, my,layer)) {
                 drawsmooth_opengl(x, y, mx, my, layer);
+            }
         }
     }
 }
@@ -565,13 +551,7 @@ static void draw_smoothing(int layer)
  * @param redraw
  */
 void opengl_gen_map(int redraw) {
-    long elapsed1, elapsed2;
-    struct timeval tv1, tv2,tv3;
     int mx,my, layer,x,y, d1, d2, d3, num_dark, got_smooth, face, t1, t2;
-
-    if (time_map_redraw)
-        gettimeofday(&tv1, NULL);
-
     glClear(GL_COLOR_BUFFER_BIT);
 
     /*
@@ -619,7 +599,9 @@ void opengl_gen_map(int redraw) {
                      * code here doesn't do anything that would extend onto the
                      * map.
                      */
-                    if (x >= use_config[CONFIG_MAPWIDTH] || y >= use_config[CONFIG_MAPHEIGHT]) continue;
+                    if (x >= use_config[CONFIG_MAPWIDTH] || y >= use_config[CONFIG_MAPHEIGHT]) {
+                        continue;
+                    }
                     /*
                      * One could make the case it doesn't make sense to light
                      * fog of war spaces, but I find visually it looks a lot
@@ -637,7 +619,7 @@ void opengl_gen_map(int redraw) {
                      * are >= check works just fine, right now.
                      */
                     if (layer == 0 && use_config[CONFIG_DARKNESS] >= CFG_LT_PIXEL &&
-~                       x <= use_config[CONFIG_MAPWIDTH] && y <= use_config[CONFIG_MAPHEIGHT]) {
+                            ~                       x <= use_config[CONFIG_MAPWIDTH] && y <= use_config[CONFIG_MAPHEIGHT]) {
                         /*
                          * The darkness code is similar to the per pixel SDL
                          * code.  As such, each square we process needs to know
@@ -653,28 +635,29 @@ void opengl_gen_map(int redraw) {
                          * But the results we use here, while perhaps not as
                          * nice, certainly look better than per tile lighting.
                          */
-                        if (the_map.cells[mx][my].have_darkness)
-                            map_darkness[x*2 + 1][y*2 + 1] = the_map.cells[mx][my].darkness;
-                        else
+                        if (mapdata_cell(mx, my)->have_darkness) {
+                            map_darkness[x*2 + 1][y*2 + 1] = mapdata_cell(mx, my)->darkness;
+                        } else {
                             map_darkness[x*2 + 1][y*2 + 1] = DEFAULT_DARKNESS;
+                        }
 
                         d1 = DEFAULT_DARKNESS;  /* square to left */
                         d2 = DEFAULT_DARKNESS;  /* square to upper left */
                         d3 = DEFAULT_DARKNESS;  /* square above */
                         num_dark=1; /* Number of adjoining spaces w/darkness */
 
-                        if (x>0 && the_map.cells[mx-1][my].have_darkness) {
-                            d1 = the_map.cells[mx-1][my].darkness;
+                        if (x>0 && mapdata_cell(mx-1, my)->have_darkness) {
+                            d1 = mapdata_cell(mx-1, my)->darkness;
                             num_dark++;
                         }
 
-                        if (x>0 && y>0 && the_map.cells[mx-1][my-1].have_darkness) {
-                            d2 = the_map.cells[mx-1][my-1].darkness;
+                        if (x>0 && y>0 && mapdata_cell(mx-1, my-1)->have_darkness) {
+                            d2 = mapdata_cell(mx-1, my-1)->darkness;
                             num_dark++;
                         }
 
-                        if (y>0 && the_map.cells[mx][my-1].have_darkness) {
-                            d3 = the_map.cells[mx][my-1].darkness;
+                        if (y>0 && mapdata_cell(mx, my-1)->have_darkness) {
+                            d3 = mapdata_cell(mx, my-1)->darkness;
                             num_dark++;
                         }
 #if 0
@@ -709,31 +692,34 @@ void opengl_gen_map(int redraw) {
 #endif
                     }
 
-                    if (the_map.cells[mx][my].heads[layer].face) {
-                        if (pixmaps[the_map.cells[mx][my].heads[layer].face]->map_texture) {
+                    if (mapdata_cell(mx, my)->heads[layer].face) {
+                        if (pixmaps[mapdata_cell(mx, my)->heads[layer].face]->map_texture) {
                             int nx, ny;
 
                             /*
                              * nx, ny are the location of the top/left side of
                              * the image to draw.
                              */
-                            nx = (x+1) * map_image_size - pixmaps[the_map.cells[mx][my].heads[layer].face]->map_width;
-                            ny = (y+1) * map_image_size - pixmaps[the_map.cells[mx][my].heads[layer].face]->map_height;
+                            nx = (x+1) * map_image_size - pixmaps[mapdata_cell(mx, my)->heads[layer].face]->map_width;
+                            ny = (y+1) * map_image_size - pixmaps[mapdata_cell(mx, my)->heads[layer].face]->map_height;
                             /*
                              * If both nx and ny are outside visible area,
                              * don't need to do anything more
                              */
-                            if (nx > width && ny > height) continue;
+                            if (nx > width && ny > height) {
+                                continue;
+                            }
                             /*
                              * There are some issues with this - it is really
                              * the head of the object that is determining fog
                              * of war logic.  I don't have good solution to
                              * that, other than to live with it.
                              */
-                            if (the_map.cells[mx][my].cleared)
-                                glBindTexture(GL_TEXTURE_2D, pixmaps[the_map.cells[mx][my].heads[layer].face]->fog_texture);
-                            else
-                                glBindTexture(GL_TEXTURE_2D, pixmaps[the_map.cells[mx][my].heads[layer].face]->map_texture);
+                            if (mapdata_cell(mx, my)->cleared) {
+                                glBindTexture(GL_TEXTURE_2D, pixmaps[mapdata_cell(mx, my)->heads[layer].face]->fog_texture);
+                            } else {
+                                glBindTexture(GL_TEXTURE_2D, pixmaps[mapdata_cell(mx, my)->heads[layer].face]->map_texture);
+                            }
 
                             glBegin(GL_QUADS);
 
@@ -751,8 +737,8 @@ void opengl_gen_map(int redraw) {
 
                             glEnd();
                         }
-                        if (use_config[CONFIG_SMOOTH] && CAN_SMOOTH(the_map.cells[mx][my],layer) &&
-                            the_map.cells[mx][my].heads[layer].face !=0) {
+                        if (use_config[CONFIG_SMOOTH] && mapdata_can_smooth(mx, my, layer) &&
+                                mapdata_cell(mx, my)->heads[layer].face !=0) {
 
                             got_smooth=1;
                         }
@@ -771,17 +757,20 @@ void opengl_gen_map(int redraw) {
                              * If both nx and ny are outside visible area,
                              * don't need to do anything more
                              */
-                            if (nx > width && ny > height) continue;
+                            if (nx > width && ny > height) {
+                                continue;
+                            }
                             /*
                              * There are some issues with this - it is really
                              * the head of the object that is determining fog
                              * of war logic.  I don't have good solution to
                              * that, other than to live with it.
                              */
-                            if (the_map.cells[mx][my].cleared)
+                            if (mapdata_cell(mx, my)->cleared) {
                                 glBindTexture(GL_TEXTURE_2D, pixmaps[face]->fog_texture);
-                            else
+                            } else {
                                 glBindTexture(GL_TEXTURE_2D, pixmaps[face]->map_texture);
+                            }
 
                             glBegin(GL_QUADS);
 
@@ -814,32 +803,17 @@ void opengl_gen_map(int redraw) {
          * smoothing to do - for many layers, this is not likely to be set, so
          * we can save work by not doing this.
          */
-        if (got_smooth)
+        if (got_smooth) {
             draw_smoothing(layer);
+        }
     }
 
-    if (time_map_redraw)
-        gettimeofday(&tv2, NULL);
-
-    #ifndef WIN32
+#ifndef WIN32
     glXSwapBuffers(display, window);
-    #else
+#else
     SwapBuffers(devicecontext);
-    #endif
-
-    if (time_map_redraw) {
-        gettimeofday(&tv3, NULL);
-        elapsed1 = (tv2.tv_sec - tv1.tv_sec)*1000000 + (tv2.tv_usec - tv1.tv_usec);
-        elapsed2 = (tv3.tv_sec - tv2.tv_sec)*1000000 + (tv3.tv_usec - tv2.tv_usec);
-        /*
-         * I care about performance for 'long' updates, so put the check in to
-         * make these a little more noticable
-         */
-        if ((elapsed1 + elapsed2)>10000)
-            LOG(LOG_INFO,"gtk-v2::opengl_gen_map","gen took %7ld, flip took %7ld, total = %7ld",
-                    elapsed1, elapsed2, elapsed1 + elapsed2);
-    }
-} /* opengl_gen_map function */
+#endif
+}
 
 /**
  * Rather than put a bunch of opengl code in the image.c file, it instead calls
@@ -848,13 +822,13 @@ void opengl_gen_map(int redraw) {
  * @param data
  * @param pi
  */
-void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
+void create_opengl_map_image(guint8 *data, PixmapInfo *pi)
 {
-    static uint8 *newdata;
+    static guint8 *newdata;
     static int size=0;
     int nwidth, nheight, numshifts, i;
-    uint8 *data_to_use = data, *l;
-    uint32 g, *p;
+    guint8 *data_to_use = data, *l;
+    guint32 g, *p;
 
     /*
      * The width and height of textures has to be a power of 2.  so 32x32 and
@@ -864,11 +838,15 @@ void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
      */
     for (nwidth = pi->map_width, numshifts=0; nwidth >1; nwidth >>=1, numshifts++) ;
     nwidth <<= numshifts;
-    if (nwidth != pi->map_width) nwidth <<=1;
+    if (nwidth != pi->map_width) {
+        nwidth <<=1;
+    }
 
     for (nheight = pi->map_height, numshifts=0; nheight >1; nheight >>=1, numshifts++) ;
     nheight <<= numshifts;
-    if (nheight != pi->map_height) nheight <<=1;
+    if (nheight != pi->map_height) {
+        nheight <<=1;
+    }
     /*
      * Below deals with cases where the pixmap is not a power of 2.  The
      * 'proper' opengl way of dealing with such textures is to make a mipmap -
@@ -884,7 +862,7 @@ void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
      */
     if (pi->map_width != nwidth || pi->map_height != nheight) {
         int y;
-        uint8   *datastart;
+        guint8   *datastart;
 
         /*
          * Use a static buffer to hold image data, so we don't have to keep
@@ -892,7 +870,13 @@ void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
          */
         if (nwidth * nheight * 4 > size) {
             size = nwidth * nheight * 4;
-            newdata = realloc(newdata, size);
+            newdata = g_realloc(newdata, size);
+
+            if (newdata == NULL) {
+                LOG(LOG_ERROR, "create_opengl_map_image",
+                        "Could not allocate memory: %s", strerror(errno));
+                exit(EXIT_FAILURE);
+            }
         }
         /*
          * Fill the top portion of the image with empty/transparent data.
@@ -902,13 +886,14 @@ void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
         if (nheight > pi->map_height) {
             memset(newdata, 0, (nheight - pi->map_height) * nwidth * 4);
             datastart = newdata + (nheight - pi->map_height) * nwidth * 4;
-        } else
+        } else {
             datastart = newdata;
+        }
 
         for (y =0; y < pi->map_height; y++) {
             memset(datastart + y * nwidth * 4, 0, (nwidth - pi->map_width) * 4);
             memcpy(datastart + y * nwidth * 4 + (nwidth - pi->map_width) * 4,
-                data + y * pi->map_width * 4, pi->map_width * 4);
+                   data + y * pi->map_width * 4, pi->map_width * 4);
         }
         data_to_use = newdata;
         pi->map_width = nwidth;
@@ -921,7 +906,7 @@ void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
     glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER, GL_LINEAR);
 
     glTexImage2D(GL_TEXTURE_2D, 0, 4, pi->map_width, pi->map_height,
-               0, GL_RGBA, GL_UNSIGNED_BYTE, data_to_use);
+                 0, GL_RGBA, GL_UNSIGNED_BYTE, data_to_use);
 
     /*
      * Generate a fog image.  This isn't 100% efficient, because we copy data
@@ -931,19 +916,19 @@ void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
 
     if (pi->map_width * pi->map_height * 4 > size) {
         size = pi->map_width * pi->map_height * 4;
-        newdata = realloc(newdata, size);
+        newdata = g_realloc(newdata, size);
     }
 
     /* In this case, newdata does not contain a copy of the data - make one */
     if (data_to_use != newdata) {
-            memcpy(newdata, data, pi->map_height *  pi->map_width * 4);
+        memcpy(newdata, data, pi->map_height *  pi->map_width * 4);
     }
 
     for (i=0; i < pi->map_width * pi->map_height; i++) {
-        l = (uint8 *) (newdata + i*4);
+        l = (guint8 *) (newdata + i*4);
         g = MAX(*l, *(l+1));
         g = MAX(g, *(l+2));
-        p = (uint32*) newdata + i;
+        p = (guint32*) newdata + i;
         *p = g | (g << 8) | (g << 16) | (*(l + 3) << 24);
     }
 
@@ -953,7 +938,7 @@ void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
     glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER, GL_LINEAR);
 
     glTexImage2D(GL_TEXTURE_2D, 0, 4, pi->map_width, pi->map_height,
-               0, GL_RGBA, GL_UNSIGNED_BYTE, newdata);
+                 0, GL_RGBA, GL_UNSIGNED_BYTE, newdata);
 }
 
 /**
@@ -1015,7 +1000,7 @@ void create_opengl_question_mark(void)
     glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER, GL_LINEAR);
 
     glTexImage2D(GL_TEXTURE_2D, 0, 4, question_width, question_height,
-               0, GL_RGBA, GL_UNSIGNED_BYTE, &question[0][0][0]);
+                 0, GL_RGBA, GL_UNSIGNED_BYTE, &question[0][0][0]);
 
     glGenTextures(1, &pixmaps[0]->fog_texture);
     glBindTexture(GL_TEXTURE_2D, pixmaps[0]->fog_texture);
@@ -1023,7 +1008,7 @@ void create_opengl_question_mark(void)
     glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER, GL_LINEAR);
 
     glTexImage2D(GL_TEXTURE_2D, 0, 4, question_width, question_height,
-               0, GL_RGBA, GL_UNSIGNED_BYTE, &question[0][0][0]);
+                 0, GL_RGBA, GL_UNSIGNED_BYTE, &question[0][0][0]);
 }
 
 #endif
